# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKIOTransformBasePython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkTransformFileWriterPython
else:
    import _itkTransformFileWriterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkTransformBasePython
import itk.itkOptimizerParametersPython
import itk.itkArrayPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkPointPython
import itk.itkArray2DPython
import itk.itkDiffusionTensor3DPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkVariableLengthVectorPython
import itk.itkTransformIOBaseTemplatePython

def itkTransformFileWriterTemplateD_New():
    return itkTransformFileWriterTemplateD.New()

class itkTransformFileWriterTemplateD(itk.ITKCommonBasePython.itkLightProcessObject):
    r"""Proxy of C++ itkTransformFileWriterTemplateD class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkTransformFileWriterTemplateD_Pointer"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkTransformFileWriterTemplateD_Pointer"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_Clone(self)

    def SetFileName(self, *args):
        r"""
        SetFileName(self, _arg)

        Parameters
        ----------
        _arg: char const *

        SetFileName(self, _arg)

        Parameters
        ----------
        _arg: std::string const &

        """
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_SetFileName(self, *args)

    def GetFileName(self):
        r"""GetFileName(self) -> char const *"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_GetFileName(self)

    def SetAppendOff(self):
        r"""SetAppendOff(self)"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_SetAppendOff(self)

    def SetAppendOn(self):
        r"""SetAppendOn(self)"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_SetAppendOn(self)

    def SetAppendMode(self, _arg):
        r"""
        SetAppendMode(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_SetAppendMode(self, _arg)

    def GetAppendMode(self, *args):
        r"""
        GetAppendMode(self) -> bool
        GetAppendMode(self) -> bool
        """
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_GetAppendMode(self, *args)

    def AppendModeOn(self):
        r"""AppendModeOn(self)"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_AppendModeOn(self)

    def AppendModeOff(self):
        r"""AppendModeOff(self)"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_AppendModeOff(self)

    def SetUseCompression(self, _arg):
        r"""
        SetUseCompression(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_SetUseCompression(self, _arg)

    def GetUseCompression(self):
        r"""GetUseCompression(self) -> bool"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_GetUseCompression(self)

    def UseCompressionOn(self):
        r"""UseCompressionOn(self)"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_UseCompressionOn(self)

    def UseCompressionOff(self):
        r"""UseCompressionOff(self)"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_UseCompressionOff(self)

    def SetInput(self, transform):
        r"""
        SetInput(self, transform)

        Parameters
        ----------
        transform: itkObject const *

        """
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_SetInput(self, transform)

    def GetInput(self):
        r"""GetInput(self) -> itkTransformBaseTemplateD"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_GetInput(self)

    def AddTransform(self, transform):
        r"""
        AddTransform(self, transform)

        Parameters
        ----------
        transform: itkObject const *

        """
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_AddTransform(self, transform)

    def Update(self):
        r"""Update(self)"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_Update(self)

    def SetTransformIO(self, _arg):
        r"""
        SetTransformIO(self, _arg)

        Parameters
        ----------
        _arg: itkTransformIOBaseTemplateD *

        """
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_SetTransformIO(self, _arg)

    def GetTransformIO(self):
        r"""GetTransformIO(self) -> itkTransformIOBaseTemplateD"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_GetTransformIO(self)
    __swig_destroy__ = _itkTransformFileWriterPython.delete_itkTransformFileWriterTemplateD

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkTransformFileWriterTemplateD

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateD_cast(obj)

    def New(*args, **kargs):
        """New() -> itkTransformFileWriterTemplateD

        Create a new object of the class itkTransformFileWriterTemplateD and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkTransformFileWriterTemplateD.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkTransformFileWriterTemplateD.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkTransformFileWriterTemplateD.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkTransformFileWriterTemplateD in _itkTransformFileWriterPython:
_itkTransformFileWriterPython.itkTransformFileWriterTemplateD_swigregister(itkTransformFileWriterTemplateD)

def itkTransformFileWriterTemplateF_New():
    return itkTransformFileWriterTemplateF.New()

class itkTransformFileWriterTemplateF(itk.ITKCommonBasePython.itkLightProcessObject):
    r"""Proxy of C++ itkTransformFileWriterTemplateF class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkTransformFileWriterTemplateF_Pointer"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkTransformFileWriterTemplateF_Pointer"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_Clone(self)

    def SetFileName(self, *args):
        r"""
        SetFileName(self, _arg)

        Parameters
        ----------
        _arg: char const *

        SetFileName(self, _arg)

        Parameters
        ----------
        _arg: std::string const &

        """
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_SetFileName(self, *args)

    def GetFileName(self):
        r"""GetFileName(self) -> char const *"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_GetFileName(self)

    def SetAppendOff(self):
        r"""SetAppendOff(self)"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_SetAppendOff(self)

    def SetAppendOn(self):
        r"""SetAppendOn(self)"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_SetAppendOn(self)

    def SetAppendMode(self, _arg):
        r"""
        SetAppendMode(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_SetAppendMode(self, _arg)

    def GetAppendMode(self, *args):
        r"""
        GetAppendMode(self) -> bool
        GetAppendMode(self) -> bool
        """
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_GetAppendMode(self, *args)

    def AppendModeOn(self):
        r"""AppendModeOn(self)"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_AppendModeOn(self)

    def AppendModeOff(self):
        r"""AppendModeOff(self)"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_AppendModeOff(self)

    def SetUseCompression(self, _arg):
        r"""
        SetUseCompression(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_SetUseCompression(self, _arg)

    def GetUseCompression(self):
        r"""GetUseCompression(self) -> bool"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_GetUseCompression(self)

    def UseCompressionOn(self):
        r"""UseCompressionOn(self)"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_UseCompressionOn(self)

    def UseCompressionOff(self):
        r"""UseCompressionOff(self)"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_UseCompressionOff(self)

    def SetInput(self, transform):
        r"""
        SetInput(self, transform)

        Parameters
        ----------
        transform: itkObject const *

        """
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_SetInput(self, transform)

    def GetInput(self):
        r"""GetInput(self) -> itkTransformBaseTemplateF"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_GetInput(self)

    def AddTransform(self, transform):
        r"""
        AddTransform(self, transform)

        Parameters
        ----------
        transform: itkObject const *

        """
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_AddTransform(self, transform)

    def Update(self):
        r"""Update(self)"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_Update(self)

    def SetTransformIO(self, _arg):
        r"""
        SetTransformIO(self, _arg)

        Parameters
        ----------
        _arg: itkTransformIOBaseTemplateF *

        """
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_SetTransformIO(self, _arg)

    def GetTransformIO(self):
        r"""GetTransformIO(self) -> itkTransformIOBaseTemplateF"""
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_GetTransformIO(self)
    __swig_destroy__ = _itkTransformFileWriterPython.delete_itkTransformFileWriterTemplateF

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkTransformFileWriterTemplateF

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkTransformFileWriterPython.itkTransformFileWriterTemplateF_cast(obj)

    def New(*args, **kargs):
        """New() -> itkTransformFileWriterTemplateF

        Create a new object of the class itkTransformFileWriterTemplateF and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkTransformFileWriterTemplateF.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkTransformFileWriterTemplateF.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkTransformFileWriterTemplateF.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkTransformFileWriterTemplateF in _itkTransformFileWriterPython:
_itkTransformFileWriterPython.itkTransformFileWriterTemplateF_swigregister(itkTransformFileWriterTemplateF)

